pub enum AssetChange {
Added(PathBuf),
Changed(PathBuf),
Deleted(PathBuf),
Unchanged(PathBuf),
}Expand description
Content change for one asset between two snapshots.
Variants
Added(PathBuf)
Asset exists only in the after snapshot.
Changed(PathBuf)
Asset exists in both snapshots but has a different content hash.
Deleted(PathBuf)
Asset exists only in the before snapshot.
Unchanged(PathBuf)
Asset exists in both snapshots with the same content hash.
Implementations