pub fn select_changed(
changes: &[AssetChange],
mode: SelectionMode,
) -> Vec<PathBuf>Expand description
Selects the assets that should be evaluated from a snapshot diff.
pub fn select_changed(
changes: &[AssetChange],
mode: SelectionMode,
) -> Vec<PathBuf>Selects the assets that should be evaluated from a snapshot diff.