pub struct BatchRubricRun<'a> { /* private fields */ }Expand description
Generic batch runner around RubricPool.
Implementations
Sourceimpl<'a> BatchRubricRun<'a>
impl<'a> BatchRubricRun<'a>
Sourcepub fn new(config: BatchRubricConfig<'a>) -> Self
pub fn new(config: BatchRubricConfig<'a>) -> Self
Creates a batch runner.
Sourcepub fn run(&self, changes: &[AssetChange]) -> BatchRubricReport
pub fn run(&self, changes: &[AssetChange]) -> BatchRubricReport
Evaluates selected assets from a snapshot diff.
Pool startup and per-asset failures are represented inside the returned report so callers can serialize the report before deciding whether to fail their own command.